# pypassman(python password manager)

**pypassman** is a command line password manager written in python programming language and it uses sqlite3 database to store the passwords.

**pypassman** requires the user to provide a 4 digit number which acts as a master password and the user can then provide user id and passwords for various websites which can be grouped as personal , work etc.



## Getting Started

### Installation

```
# Using PyPI
pip3 install pypassman
```

### Running the program

```
pypassman
```

